@@ -35,8 +35,8 @@ class AutoRepr:
 
 @AutoRepr
 class Event:
-    def __init__(self, __event_name, *args, **kwargs):
-        self.name: str = __event_name
+    def __init__(self, __event_name: str, *args, **kwargs):
+        self.name: str = __event_name.lower()
         self.args: ty.Tuple = args
         self.kwargs: ty.Dict = kwargs
 
@@ -49,7 +49,6 @@ class Event:
         elif self.name.startswith(router.name) and router.parent:
             self.name = f":{self.name}"
 
-        print(f"{self.name}")
         return self
 
     def lower(self):
@@ -102,7 +101,6 @@ class EventMuxer:
 
     @router.setter
     def router(self, router: EventRouter):
-        print(f"Attaching router {router} to {self}")
         if self.__router:
             raise ValueError(f"Attempted to set another router for {self}")
         else:
@@ -110,8 +108,8 @@ class EventMuxer:
 
 
 class EventRouter:
-    def __init__(self, name, parent: EventRouter = None):
-        self.name = name
+    def __init__(self, name: str, parent: EventRouter = None):
+        self.name = name.lower()
         self.parent = parent
         if self.parent:
             # self.name = f":{self.name}"
@@ -119,8 +117,6 @@ class EventRouter:
         self.listeners: ty.Dict[str, EventMuxer] = {}
 
     def endpoint(self, name: str, decompose=False):
-        # print(f"attaching endpoint {name} to {self}")
-        # print(f"{self} now has endpoint {self.name}")
         def __decorator(func: ty.Callable[[...], ty.Awaitable]):
             if not asyncio.iscoroutinefunction(func):
                 @fnt.wraps(func)
@@ -136,13 +132,15 @@ class EventRouter:
                     return await func(*event.args, **event.kwargs)
 
                 _func = __decompose
-            logging.debug("[%s] Attaching endpoint %s:%s as <%s>", self, func.__name__, func.__annotations__, name)
+            logging.debug("[%s] Attaching endpoint %s as <%s>", self, func.__name__, name.lower())
 
-            self.register_listener(name=name, listener=_func)
+            self.register_listener(name=name.lower(), listener=_func)
             return func
+
         return __decorator
 
     def register_listener(self, name: str, listener: ty.Union[EventFunction, EventRouter, EventWaiter]):
+        name = name.lower()
         logging.debug("[%s] Registering listener %s as <%s>", self, listener, name)
         if isinstance(listener, EventRouter):
             if ":" in name:
